@@ -26,8 +26,9 @@ class StaticRequireListRenderer implements StaticListRenderer {
      */
     public function render(array $list) {
         $require = (boolean)$this->useOnce ? 'require_once' : 'require';
-        $glue = ';' . $this->linebreak . $this->indent . $require . ' ';
+        $require .= ' ___BASEDIR___\'';
+        $glue = '\';' . $this->linebreak . $this->indent . $require;
 
-        return $this->indent . $require . ' ' . implode($glue, $list) . ';';
+        return $this->indent . $require . implode($glue, $list) . '\';';
     }
 }
